@@ -9,11 +9,14 @@ import time
 import sys
 import os
 import getpass
+import pwd
 from ConfigParser import ConfigParser, Error as ConfigParserError
 from StringIO import StringIO
 
 from dbus.exceptions import DBusException
 
+from landscape.lib.tag import is_valid_tag
+
 from landscape.sysvconfig import SysVConfig, ProcessError
 from landscape.lib.dbus_util import (
     get_bus, NoReplyError, ServiceUnknownError, SecurityError)
@@ -41,6 +44,27 @@ def print_text(text, end="\n", error=False):
     stream.flush()
 
 
+def get_invalid_users(users):
+    """
+    Process a string with a list of comma separated usernames, this returns
+    any usernames not known to the underlying user database.
+    """
+    if users is not None:
+        user_list = [user.strip() for user in users.split(",")]
+        if "ALL" in user_list:
+            if len(user_list) > 1:
+                raise ConfigurationError(
+                    "Extra users specified with ALL users")
+            user_list.remove("ALL")
+        invalid_users = []
+        for user in user_list:
+            try:
+                pwd.getpwnam(user)
+            except KeyError:
+                invalid_users.append(user)
+        return invalid_users
+
+
 class LandscapeSetupConfiguration(BrokerConfiguration):
 
     unsaved_options = ("no_start", "disable", "silent", "ok_no_register",
@@ -139,6 +163,20 @@ class LandscapeSetupScript(object):
         lines = text.strip().splitlines()
         print_text("\n"+"".join([line.strip()+"\n" for line in lines]))
 
+    def prompt_get_input(self, msg, required):
+        """Prompt the user on the terminal for a value
+
+        @param msg: Message to prompt user with
+        @param required: True if value must be entered
+        """
+        while True:
+            value = raw_input(msg)
+            if value:
+                return value
+            elif not required:
+                break
+            self.show_help("This option is required to configure Landscape.")
+
     def prompt(self, option, msg, required=False):
         """Prompt the user on the terminal for a value.
 
@@ -153,14 +191,10 @@ class LandscapeSetupScript(object):
             msg += " [%s]: " % default
         else:
             msg += ": "
-        while True:
-            value = raw_input(msg)
-            if value:
-                setattr(self.config, option, value)
-                break
-            elif default or not required:
-                break
-            self.show_help("This option is required to configure Landscape.")
+        required = required and not (bool(default))
+        result = self.prompt_get_input(msg, required)
+        if result:
+            setattr(self.config, option, result)
 
     def password_prompt(self, option, msg, required=False):
         """Prompt the user on the terminal for a password and mask the value.
@@ -274,8 +308,11 @@ class LandscapeSetupScript(object):
     def query_script_plugin(self):
         options = self.config.get_command_line_options()
         if "include_manager_plugins" in options and "script_users" in options:
+            invalid_users = get_invalid_users(options["script_users"])
+            if invalid_users:
+                raise ConfigurationError("Unknown system users: %s" %
+                                         ", ".join(invalid_users))
             return
-
         self.show_help(
             """
             Landscape has a feature which enables administrators to run
@@ -300,13 +337,53 @@ class LandscapeSetupScript(object):
                 that scripts will be restricted to. To allow scripts to be run
                 by any user, enter "ALL".
                 """)
-            if not "script_users" in options:
+            while True:
                 self.prompt("script_users", "Script users")
+                invalid_users = get_invalid_users(
+                    self.config.script_users)
+                if not invalid_users:
+                    break
+                else:
+                    self.show_help("Unknown system users: %s" %
+                                   ",".join(invalid_users))
+                    self.config.script_users = None
         else:
             if "ScriptExecution" in included_plugins:
                 included_plugins.remove("ScriptExecution")
         self.config.include_manager_plugins = ", ".join(included_plugins)
 
+    def _get_invalid_tags(self, tagnames):
+        """
+        Splits a string on , and checks the validity of each tag, returns any
+        invalid tags.
+        """
+        invalid_tags = []
+        if tagnames:
+           tags  = [tag.strip() for tag in tagnames.split(",")]
+           invalid_tags = [tag for tag in tags if not is_valid_tag(tag)]
+        return invalid_tags
+
+    def query_tags(self):
+        """Query tags from the user."""
+        options = self.config.get_command_line_options()
+        if "tags" in options:
+            invalid_tags = self._get_invalid_tags(options["tags"])
+            if invalid_tags:
+                raise ConfigurationError("Invalid tags: %s" %
+                                         ", ".join(invalid_tags))
+            return
+
+        self.show_help("You may provide tags for this computer e.g. "
+                       "server,hardy.")
+        while True:
+            self.prompt("tags", "Tags", False)
+            if self._get_invalid_tags(self.config.tags):
+               self.show_help("Tag names may only contain alphanumeric "
+                              "characters.")
+               self.config.tags = None # Reset for the next prompt
+            else:
+                break
+
     def show_header(self):
         self.show_help(
             """
@@ -330,6 +407,7 @@ class LandscapeSetupScript(object):
         self.query_registration_password()
         self.query_proxies()
         self.query_script_plugin()
+        self.query_tags()
 
 
 def setup_init_script_and_start_client():
@@ -367,15 +445,20 @@ def setup(config):
         if not config.get("account_name") or not config.get("computer_title"):
             raise ConfigurationError("An account name and computer title are "
                                      "required.")
-        if config.get("script_users") and not config.include_manager_plugins:
-            config.include_manager_plugins = "ScriptExecution"
+        if config.get("script_users"):
+            invalid_users = get_invalid_users(config.get("script_users"))
+            if invalid_users:
+                raise ConfigurationError("Unknown system users: %s" %
+                                         ", ".join(invalid_users))
+            if not config.include_manager_plugins:
+                config.include_manager_plugins = "ScriptExecution"
     else:
         script = LandscapeSetupScript(config)
         script.run()
-    
+
     if config.ssl_public_key and config.ssl_public_key.startswith("base64:"):
         key_filename = config.get_config_filename() + ".ssl_public_key"
-        print_text("Writing SSL public key to %s..." % key_filename)
+        print_text("Writing SSL CA certificate to %s..." % key_filename)
         decoded_key = base64.decodestring(config.ssl_public_key[7:])
         key_file = open(key_filename, "w")
         key_file.write(decoded_key)
@@ -411,7 +494,7 @@ def register(config, reactor=None):
     install()
     if reactor is None:
         from twisted.internet import reactor
-    
+
     # XXX: many of these reactor.stop() calls should also specify a non-0 exit
     # code, unless ok-no-register is passed.
 
