@@ -140,9 +140,10 @@ REGISTER = Message(
     {"registration_password": Any(utf8, Constant(None)),
      "computer_title": utf8,
      "hostname": utf8,
-     "account_name": utf8},
+     "account_name": utf8,
+     "tags": Any(utf8, Constant(None))},
     # hostname wasn't around in old versions
-    optional=["registration_password", "hostname"])
+    optional=["registration_password", "hostname", "tags"])
 
 REGISTER_CLOUD_VM = Message(
     "register-cloud-vm",
@@ -158,7 +159,8 @@ REGISTER_CLOUD_VM = Message(
      "ramdisk_key": Unicode(),
      "launch_index": Int(),
      "image_key": Unicode(),
-     })
+     "tags": Any(utf8, Constant(None))},
+     optional=["tags"])
 
 TEMPERATURE = Message("temperature", {
     "thermal-zone": utf8,
@@ -338,6 +340,23 @@ REBOOT_REQUIRED = Message(
     "reboot-required",
     {"flag": Bool()})
 
+APT_PREFERENCES = Message(
+    "apt-preferences",
+    {"data": Any(Dict(Unicode(), Unicode()), Constant(None))})
+
+EUCALYPTUS_INFO = Message(
+    "eucalyptus-info",
+    {"basic_info": Dict(String(), Any(String(), Constant(None))),
+     "walrus_info": String(),
+     "cluster_controller_info": String(),
+     "storage_controller_info": String(),
+     "node_controller_info": String()})
+
+EUCALYPTUS_INFO_ERROR = Message(
+    "eucalyptus-info-error",
+    {"error": String()})
+
+
 message_schemas = {}
 for schema in [ACTIVE_PROCESS_INFO, COMPUTER_UPTIME, CLIENT_UPTIME,
                OPERATION_RESULT, COMPUTER_INFO, DISTRIBUTION_INFO,
@@ -347,5 +366,6 @@ for schema in [ACTIVE_PROCESS_INFO, COMPUTER_UPTIME, CLIENT_UPTIME,
                USERS, PACKAGES, PACKAGE_LOCKS,
                CHANGE_PACKAGES_RESULT, UNKNOWN_PACKAGE_HASHES,
                ADD_PACKAGES, TEXT_MESSAGE, TEST, CUSTOM_GRAPH,
-               REBOOT_REQUIRED]:
+               REBOOT_REQUIRED, APT_PREFERENCES, EUCALYPTUS_INFO,
+               EUCALYPTUS_INFO_ERROR]:
     message_schemas[schema.type] = schema
