@@ -10,7 +10,7 @@ from landscape.monitor.activeprocessinfo import ActiveProcessInfo
 from landscape.tests.helpers import (LandscapeTest, MonitorHelper,
                                      ProcessDataBuilder)
 from landscape.tests.mocker import ANY
-from landscape import API
+from landscape import SERVER_API
 
 
 class ActiveProcessInfoTest(LandscapeTest):
@@ -470,7 +470,7 @@ class ActiveProcessInfoTest(LandscapeTest):
         messages = self.mstore.get_pending_messages()
         self.assertEquals(len(messages), 2)
         self.assertMessages(messages, [{"timestamp": 0,
-                                        "api": API,
+                                        "api": SERVER_API,
                                         "type": "active-process-info",
                                         "kill-all-processes": True,
                                         "add-processes": [{"start-time": 110,
@@ -482,7 +482,7 @@ class ActiveProcessInfoTest(LandscapeTest):
                                                             "vm-size": 11676,
                                                             "uid": 0}]},
                                        {"timestamp": 0,
-                                        "api": API,
+                                        "api": SERVER_API,
                                         "type": "active-process-info",
                                         "update-processes": [{"start-time": 110,
                                                               "name": u"init",
