@@ -15,6 +15,7 @@ from twisted.internet.process import Process, ProcessReader
 from landscape.lib.fetch import url_to_filename, fetch_to_files
 from landscape.lib.lsb_release import parse_lsb_release, LSB_RELEASE_FILENAME
 from landscape.lib.gpg import gpg_verify
+from landscape.lib.fs import read_file
 from landscape.package.taskhandler import (
     PackageTaskHandlerConfiguration, PackageTaskHandler, run_task_handler)
 from landscape.manager.manager import SUCCEEDED, FAILED
@@ -33,12 +34,25 @@ class ReleaseUpgraderConfiguration(PackageTaskHandlerConfiguration):
 
 
 class ReleaseUpgrader(PackageTaskHandler):
-    """Perform release upgrades."""
+    """Perform release upgrades.
+
+    @cvar config_factory: The configuration class to use to build configuration
+        objects to be passed to our constructor.
+    @cvar queue_name: The queue we pick tasks from.
+    @cvar lsb_release_filename: The path to the LSB data on the file system.
+    @cvar landscape_ppa_url: The URL of the Landscape PPA, if it is present
+        in the computer's sources.list it won't be commented out.
+    @cvar logs_directory: Path to the directory holding the upgrade-tool logs.
+    @cvar logs_limit: When reporting upgrade-tool logs to the server, only the
+        last C{logs_limit} lines will be sent.
+    """
 
     config_factory = ReleaseUpgraderConfiguration
     queue_name = "release-upgrader"
     lsb_release_filename = LSB_RELEASE_FILENAME
-    landscape_ppa_url = "http://ppa.launchpad.net/landscape/ppa/ubuntu/"
+    landscape_ppa_url = "http://ppa.launchpad.net/landscape/trunk/ubuntu/"
+    logs_directory = "/var/log/dist-upgrade"
+    logs_limit = 100000
 
     def make_operation_result_message(self, operation_id, status, text, code):
         """Convenience to create messages of type C{"operation-result"}."""
@@ -180,7 +194,7 @@ class ReleaseUpgrader(PackageTaskHandler):
             if not config.has_section("Distro"):
                 config.add_section("Distro")
             if not config.has_option("Distro", "PostInstallScripts"):
-                config.set("Distro", "PostInstallScripts", "./dbus/sh")
+                config.set("Distro", "PostInstallScripts", "./dbus.sh")
             else:
                 scripts = config.get("Distro", "PostInstallScripts")
                 scripts += ", ./dbus.sh"
@@ -210,6 +224,28 @@ class ReleaseUpgrader(PackageTaskHandler):
 
         return succeed(None)
 
+    def make_operation_result_text(self, out, err):
+        """Return the operation result text to be sent to the server.
+
+        @param out: The standard output of the upgrade-tool process.
+        @param err: The standard error of the upgrade-tool process.
+        @return: A text aggregating the process output, error and log files.
+        """
+        buf = cStringIO.StringIO()
+
+        for label, content in [("output", out), ("error", err)]:
+            if content:
+                buf.write("=== Standard %s ===\n\n%s\n\n" % (label, content))
+
+        for basename in sorted(os.listdir(self.logs_directory)):
+            if not basename.endswith(".log"):
+                continue
+            filename = os.path.join(self.logs_directory, basename)
+            content = read_file(filename, - self.logs_limit)
+            buf.write("=== %s ===\n\n%s\n\n" % (basename, content))
+
+        return buf.getvalue()
+
     def upgrade(self, code_name, operation_id, allow_third_party=False,
                 debug=False, mode=None):
         """Run the upgrade-tool command and send a report of the results.
@@ -267,8 +303,9 @@ class ReleaseUpgrader(PackageTaskHandler):
                 status = SUCCEEDED
             else:
                 status = FAILED
-            message = self.make_operation_result_message(
-                operation_id, status, "%s%s" % (out, err), code)
+            text = self.make_operation_result_text(out, err)
+            message = self.make_operation_result_message(operation_id, status,
+                                                         text, code)
             logging.info("Queuing message with release upgrade results to "
                          "exchange urgently.")
             return self._broker.send_message(message, True)
